## `aws-annoying session-manager install`

::: aws_annoying.cli.session_manager.install.install
    options:
        show_signature: false

## `aws-annoying session-manager port-forward`

::: aws_annoying.cli.session_manager.port_forward.port_forward
    options:
        show_signature: false

## `aws-annoying session-manager start`

::: aws_annoying.cli.session_manager.start.start
    options:
        show_signature: false

## `aws-annoying session-manager stop`

::: aws_annoying.cli.session_manager.stop.stop
    options:
        show_signature: false
